@@ -6,8 +6,7 @@ import logging
 from colorama import Fore, Style
 
 from nlab_inf_engine_scripts.InfEngineServer import InfEngineServer
-
-VERSION = "0.0.17"
+from nlab_inf_engine_scripts.version import VERSION
 
 
 def main():
@@ -39,18 +38,7 @@ def main():
         help=f"Enable DEBUG level logging.",
     )
 
-    group = parser.add_argument_group("InfServer").add_mutually_exclusive_group()
-    group.add_argument("--start", action="store_true", help=f"Start InfServer.")
-    group.add_argument("--stop", action="store_true", help=f"Stop InfServer.")
-    group.add_argument("--restart", action="store_true", help=f"Restart InfServer.")
-    group.add_argument("--respawn", action="store_true", help=f"Respawn InfServer.")
-    group.add_argument("--status", action="store_true", help=f"Get InfServer status.")
-    group.add_argument(
-        "--version", action="store_true", help=f"Print package version and exit."
-    )
-    group.add_argument(
-        "--engine-version", action="store_true", help=f"Print engine version and exit."
-    )
+    group = parser.add_argument_group("DL Compilation").add_mutually_exclusive_group()
     group.add_argument(
         "--dl-update",
         action="store",
@@ -69,6 +57,32 @@ def main():
         "--dl-delete-all", action="store_true", help=f"Delete all DL data."
     )
 
+    group = parser.add_argument_group("DL Compilation Options")
+    group.add_argument(
+        "--db-name",
+        action="store",
+        default="dldata",
+        help=f"Specify DL binary name. Default: dldata",
+    )
+    group.add_argument(
+        "--dl-verbose",
+        action="store_true",
+        help=f"Enable DEBUG level logging.",
+    )
+
+    group = parser.add_argument_group("InfServer").add_mutually_exclusive_group()
+    group.add_argument("--start", action="store_true", help=f"Start InfServer.")
+    group.add_argument("--stop", action="store_true", help=f"Stop InfServer.")
+    group.add_argument("--restart", action="store_true", help=f"Restart InfServer.")
+    group.add_argument("--respawn", action="store_true", help=f"Respawn InfServer.")
+    group.add_argument("--status", action="store_true", help=f"Get InfServer status.")
+    group.add_argument(
+        "--version", action="store_true", help=f"Print package version and exit."
+    )
+    group.add_argument(
+        "--engine-version", action="store_true", help=f"Print engine version and exit."
+    )
+
     args = parser.parse_args()
 
     root_path = args.root_path[0] if args.root_path else None
@@ -120,7 +134,7 @@ def main():
             print(f"{server.version()}")
         elif args.dl_update:
             print(" * Update data", end="")
-            server.update_data(dldata=args.dl_update)
+            server.update_data(dldata=args.dl_update, db_name=args.db_name)
             success()
         elif args.dl_delete:
             print(" * Delete data", end="")
