@@ -108,6 +108,7 @@ class InfEngineServer:
         self._logger.addHandler(handler)
 
         if enable_logging:
+            formatter = logging.Formatter(fmt=" * %(message)s")
             handler = logging.StreamHandler()
             handler.setFormatter(formatter)
             self._logger.addHandler(handler)
@@ -412,7 +413,11 @@ class InfEngineServer:
             return "NOT RUNNING"
 
     def update_data(
-        self, dldata: str = None, dlsources: str = None, strict: bool = False
+        self,
+        dldata: str = None,
+        dlsources: str = None,
+        strict: bool = False,
+        db_name: str = "dldata",
     ):
         """ Update DL data. """
 
